@@ -79,7 +79,7 @@ char *number(char *sp, int *intPtr) {
 	char *retval;
 
 	if(sp==NULL) {
-		*intPtr=0; 
+		*intPtr=0;
 		retval = sp;
 	}
 	else {
@@ -112,7 +112,7 @@ char *get_long(char *sp, long *intPtr) {
 	char *retval;
 
 	if(sp==NULL) {
-		*intPtr=0; 
+		*intPtr=0;
 		retval = sp;
 	}
 	else {
@@ -139,42 +139,35 @@ char *get_long(char *sp, long *intPtr) {
 }
 
 /*---------------------------------------------*/
-struct hostent *get_hostent(const char *host) {
-	struct in_addr saddr;
-	int c;
-	struct hostent *hi = NULL;
+struct addrinfo *get_addrinfo(const char *host, const char *sport) {
+	struct addrinfo hints = { .ai_socktype=SOCK_STREAM, .ai_flags = AI_CANONNAME };
+	struct addrinfo * res = NULL;
 
-	if(host==NULL) { 
-		error_log(ERRLOG_REPORT,both_phrases[0], NULL); 
+	if(host==NULL) {
+		error_log(ERRLOG_REPORT,both_phrases[0], NULL);
 	}
 	else {
-		c=*host;
-		if(isdigit(c)) {
- 			saddr.s_addr = inet_addr(host); 
- 			hi = gethostbyaddr((char *)&saddr,sizeof(struct in_addr),AF_INET);
-		}
-		else {
-			hi = gethostbyname(host);
+		int st = getaddrinfo(host, sport, &hints, &res);
+		if (st < 0) {
+			error_log(ERRLOG_REPORT, "%v1%: %v2%: %v3%\n", host, both_phrases[2], gai_strerror(st), NULL);
 		}
 	}
-	return hi;
+	return res;
 }
 /*--------------------------------------------*/
-int connect_to_nntphost(const char *host, struct hostent **hi, FILE *msgs, unsigned short int portnr, int do_ssl, void **ssl) {
-	char *ptr, *realhost;
-	struct in_addr *aptr;
-	struct in_addr saddr;
-	struct sockaddr_in address;
+int connect_to_nntphost(const char *host, char * name, size_t namelen, FILE *msgs, unsigned short int portnr, int do_ssl, void **ssl) {
+	char *realhost;
 	char sport[10];
 	int sockfd = -1;
-	
+	struct addrinfo * ai;
+	char buffer[60]; // if not given by caller. NI_MAXHOST would be better, but that's ok as well.
+
 #ifdef HAVE_LIBSSL
 	SSL *ssl_struct = NULL;
 	SSL_CTX *test1 = NULL;
-	
+
 	if(do_ssl == TRUE) {
 		(void) SSL_library_init();
-
 		test1 = SSL_CTX_new(SSLv23_client_method());
 		if(test1 == NULL) {
 			/* whoops */
@@ -183,66 +176,65 @@ int connect_to_nntphost(const char *host, struct hostent **hi, FILE *msgs, unsig
 		}
 	}
 #endif
+	if (!name) {
+		name = buffer;
+		namelen = sizeof buffer;
+	}
 	/* handle host:port type syntax */
 	realhost = strdup(host);
 	if(realhost == NULL) {
 		MyPerror("out of memory copying host name");
 		return sockfd;
 	}
-	ptr = strchr(realhost, ':');
+	char * ptr = strchr(realhost, ':');
 	if(ptr != NULL) {
 		*ptr = '\0';  /* null terminate host name */
 		portnr = atoi(++ptr); /* get port number */
 	}
-	
-	
-	
+
+
+
 	sprintf(sport, "%hu", portnr);	/* cause print_phrases wants all strings */
 	print_phrases(msgs, both_phrases[1], sport, NULL);
 
-	/* Find the internet address of the NNTP server */
- 	*hi = get_hostent(realhost);
- 	if(*hi == NULL) {
-		error_log(ERRLOG_REPORT,"%v1%: ",realhost, NULL);
-  		MyPerror(both_phrases[2]);
+	/* Find the internet addresses of the NNTP server */
+	ai = get_addrinfo(realhost, sport);
+	if(ai == NULL) {
 		free(realhost);
- 	}
+	}
 	else {
 		free(realhost);
-		print_phrases(msgs, both_phrases[3], (*hi)->h_name, NULL);
- 		while((ptr = *((*hi)->h_aliases)) != NULL) {
-			print_phrases(msgs, both_phrases[4], ptr, NULL );
-			(*hi)->h_aliases++;
-		}
- 		if((*hi)->h_addrtype != AF_INET) {
-  			error_log(ERRLOG_REPORT, both_phrases[5], NULL);
-		}
-		else {
-			while((aptr = (struct in_addr *)*((*hi)->h_addr_list)++) != NULL) {
-				saddr = *aptr;
-				print_phrases(msgs, both_phrases[17], inet_ntoa(*aptr), NULL);
+		struct addrinfo * aii;
+		print_phrases(msgs, both_phrases[3], ai->ai_canonname, NULL);
+		for (aii=ai; aii; aii=aii->ai_next) {
+			if (getnameinfo(aii->ai_addr, aii->ai_addrlen, name, namelen, NULL, 0, NI_NUMERICHOST) < 0) {
+				name[0] = '\0';
 			}
-
 			/* Create a socket */
- 			if((sockfd = socket( AF_INET, SOCK_STREAM, SOCKET_PROTOCOL)) == -1) {
-				MyPerror(both_phrases[6]);
+			if((sockfd = socket(aii->ai_family, aii->ai_socktype, aii->ai_protocol)) == -1) {
+				continue; // MyPerror(both_phrases[6]);
 			}
-			else { 
-				address.sin_family = AF_INET;
-				address.sin_port = htons(portnr);  /* NNTP port */
-				address.sin_addr= saddr;
-
+			else {
 				/* Establish a connection */
-				if(connect(sockfd, (struct sockaddr *)&address, sizeof address ) == -1) {
-					MyPerror(both_phrases[7]);
+				if(connect(sockfd, aii->ai_addr, aii->ai_addrlen ) == -1) {
+					//MyPerror(both_phrases[7]);
 					close(sockfd);
 					sockfd = -1;
+					continue;
 				}
 				else {
-					print_phrases(msgs,both_phrases[8], (*hi)->h_name, NULL);
+					int st = getnameinfo(aii->ai_addr, aii->ai_addrlen, name, namelen,
+						NULL, 0, NI_NUMERICHOST);
+					print_phrases(msgs, both_phrases[8],st == 0 ? name : host, NULL);
+					if (st != 0) name[0] = '\0';
+					break;
 				}
 			}
 		}
+		freeaddrinfo(ai);
+		if (sockfd < 0) {
+			MyPerror(both_phrases[6]); // or 7?
+		}
 #ifdef HAVE_LIBSSL
 		if(sockfd > -1 && do_ssl == TRUE) {
 			if((ssl_struct = SSL_new(test1)) == NULL) {
@@ -263,7 +255,7 @@ int connect_to_nntphost(const char *host, struct hostent **hi, FILE *msgs, unsig
 			else {
 				*ssl = ssl_struct;
 			}
-			
+
 		}
 #endif
 	}
@@ -280,11 +272,11 @@ void disconnect_from_nntphost(int fd, int do_ssl, void **ssl) {
 	}
 #endif
 	close(fd);
-	
+
 }
 /*----------------------------------------------------------------*/
 int sputline(int fd, const char *outbuf, int do_ssl, void *ssl_buf) {
-	
+
 #ifdef DEBUG1
 	do_debug("\nSENT: %s", outbuf);
 #endif
@@ -310,7 +302,7 @@ void do_debug(const char *fmt, ...) {
 	if((fptr = fopen(N_DEBUG, "a")) == NULL) {
 		fptr = stderr;
 	}
-		
+
 	va_start(args, fmt);
 	vfprintf(fptr, fmt, args);
 	va_end(args);
@@ -335,7 +327,7 @@ void do_debug_binary(int len, const char *str) {
 /*-----------------------------------------------------------*/
 void do_debug_vl(const char *fmt, va_list args) {
 	FILE *fptr = NULL;
-	
+
 	if((fptr = fopen(N_DEBUG, "a")) == NULL) {
 		fptr = stderr;
 	}
@@ -352,14 +344,14 @@ void MyPerror(const char *message) {
 	/* can't just use perror, since it goes to stderr */
 	/* and I need to route it to my errlog */
 	/* so I have to recreate perror's format */
-	
+
 	/* in case of NULL ptr */
-	
+
 	if(message == NULL) {
 		message="";
 	}
 #ifdef HAVE_STRERROR
-	error_log(ERRLOG_REPORT, "%v1%: %v2%\n", message, strerror(errno), NULL);	  
+	error_log(ERRLOG_REPORT, "%v1%: %v2%\n", message, strerror(errno), NULL);
 #else
 	error_log(ERRLOG_REPORT, both_phrases[9], message, errno, NULL);
 #endif
@@ -397,8 +389,8 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 		ret = -1;
 	}
 	else if(eob == start || (ptr = findnl(start, eob)) == NULL) {
-		
-		/* TEST for not a full line in buffer */	
+
+		/* TEST for not a full line in buffer */
 		/* the eob == start test is needed in case the buffer is */
 		/* empty, since we don't know what is in it. */
 
@@ -424,7 +416,7 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 			FD_SET(fd, &myset);
 			mytimes.tv_sec = TimeOut;
 			mytimes.tv_usec = 0;
-	
+
 #ifdef MYSIGNAL
 			signal_block(MYSIGNAL_BLOCK);
 			/* block so we can't get interrupted by our signal defined in config.h */
@@ -471,7 +463,7 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 				}
 			}
 			else
-#endif		
+#endif
 			i = recv(fd, eob, MAXLINLEN-len, 0);	/* get line */
 #endif
 
@@ -486,7 +478,7 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 				do_debug_binary(i,eob);
 				do_debug(":END GOT");
 			}
-			
+
 #endif
 
 			if(i < 1) {
@@ -504,7 +496,7 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 				eob += i;	/* increment buffer end */
 				*eob = '\0';	/* NULL terminate it  */
 
-				len += i;				
+				len += i;
 				ptr = findnl(start, eob);
 			}
 		} while(ptr == NULL && len < MAXLINLEN && ret == 0);
@@ -548,7 +540,7 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 	else {
 		do_debug("\nRETURNING error, ret = %d", ret);
 	}
-#endif  
+#endif
 	if(eob == start) {
 		/* nothing left in buffer, reset pointers to start of buffer */
 		/* to give us a full buffer to receive next data into */
@@ -563,11 +555,11 @@ int sgetline(int fd, char **inbuf, int do_ssl, void *ssl_buf) {
 	}
 
 	return ret;
-}		
+}
 /*----------------------------------------------------*/
 #ifdef MYSIGNAL
 void signal_block(int action) {
-#ifdef HAVE_SIGACTION	
+#ifdef HAVE_SIGACTION
 	static sigset_t blockers;
 	static int do_block = FALSE;
 
@@ -590,7 +582,7 @@ void signal_block(int action) {
 			if(do_block == TRUE) {
 				if(sigprocmask(SIG_BLOCK, &blockers, NULL) == -1) {
 					MyPerror(both_phrases[13]);
-				}	
+				}
 			}
 			break;
 		case MYSIGNAL_UNBLOCK:
@@ -615,9 +607,9 @@ void error_log(int mode, const char *fmt, ...) {
 	va_list args;
 	static char errfile[PATH_MAX] = { '\0' };
 	static int debug = FALSE;
-	
+
 	va_start(args, fmt);	/* set up args */
-	
+
 	switch(mode) {
 	  case ERRLOG_SET_DEBUG:
 		debug = TRUE;
@@ -681,7 +673,7 @@ char **build_args(const char *fname, int *nrargs) {
 		}
 #ifdef DEBUG1
 		do_debug("Counted %d args in %s\n", counter, fname);
-#endif  
+#endif
 		if((args = calloc( counter, sizeof(char *))) == NULL) {
 			error_log(ERRLOG_REPORT, both_phrases[15], fname, NULL);
 		}
@@ -780,7 +772,7 @@ void free_array(int n, char **arr) {
 			}
 		}
 		free(arr);
-	}	
+	}
 }
 /*--------------------------------------------------------------------------------*/
 char *do_a_phrase(char linein[]) {
@@ -789,10 +781,10 @@ char *do_a_phrase(char linein[]) {
 	int i, stt, end;
 	static char default_phrase[] = "";
 
-	
+
 	i = strlen(linein);
 	lineout = NULL;
-	
+
 	/* find start and finish of string */
 	for(stt = 0; stt != i && linein[stt] != '"'; stt++) {
 	}
@@ -845,17 +837,17 @@ void convert_nl(char *linein) {
 					for ( x = i + 1; x < len ; x++ ) {
 						linein[x] = linein[x+1];
 					}
-					len--;		
+					len--;
 				}
 			}
 		}
-	}				
+	}
 }
 /*-----------------------------------------------------------------------------------*/
 void print_phrases(FILE *fpout, const char *argstr, ... ){
 
 	va_list vargs;
-	
+
 	va_start(vargs, argstr);
 
 	if(fpout != NULL) {
@@ -869,7 +861,7 @@ void print_phrases(FILE *fpout, const char *argstr, ... ){
 /*-----------------------------------------------------------------------------------*/
 void vprint_phrases(FILE *fpout, const char *argstr, va_list vargs) {
 	/* this routine takes in argstr, parses it for args and prints everything */
-	/* out, the args may not be in order ("hi %v2% there %v1% guys")	  */  
+	/* out, the args may not be in order ("hi %v2% there %v1% guys")	  */
 	/* args are %v#%.  The varargs are all char ptrs */
 
 	const char *ptr, *pnumber;
@@ -882,7 +874,7 @@ void vprint_phrases(FILE *fpout, const char *argstr, va_list vargs) {
 	while(tptr != NULL && nrvars < PHRASES_MAX_NR_VARS) {
 		in[nrvars++] = tptr;
 		tptr = va_arg(vargs, char *);
-	}		
+	}
 
 	varyn = FALSE;
 	ptr = argstr;
@@ -910,7 +902,6 @@ void vprint_phrases(FILE *fpout, const char *argstr, va_list vargs) {
 							fputs(in[vnr-1], fpout);
 							ptr = pnumber+1;	/* advance past var */
 						}
-							
 					}
 				}
 				if(varyn == FALSE) {
@@ -929,30 +920,30 @@ void vprint_phrases(FILE *fpout, const char *argstr, va_list vargs) {
 }
 /*----------------------------------------------------------*/
 char *str_int(int nrin) {
-	
+
 	static char strings[PHRASES_MAX_NR_VARS][12];	/* lets pray ints don't get bigger than this */
 	static int which = 0;
-	
+
 	/* use a set of rotating buffers so can make multiple str_int calls */
 	if(++which == PHRASES_MAX_NR_VARS) {
 		which = 0;
 	}
-	
+
 	sprintf(strings[which], "%d", nrin);
 
 	return strings[which];
 }
 /*----------------------------------------------------------*/
 char *str_long(long nrin) {
-	
+
 	static char strings[PHRASES_MAX_NR_VARS][20];	/* lets pray longs don't get bigger than this */
 	static int which = 0;
-	
+
 	/* use a set of rotating buffers so can make multiple str_int calls */
 	if(++which == PHRASES_MAX_NR_VARS) {
 		which = 0;
 	}
-	
+
 	sprintf(strings[which], "%ld", nrin);
 
 	return strings[which];
