@@ -4,7 +4,7 @@
 #include <stdarg.h>
 
 #define LENGTHLEN 8
-/*#define DEBUG*/
+#define DEBUG 1
 
 #ifdef DEBUG
 #define N_DEBUG "debug.child"
@@ -56,7 +56,7 @@ void do_debug(const char *fmt, ...) {
 	if((fptr = fopen(N_DEBUG, "a")) == NULL) {
 		fptr = stderr;
 	}
-		
+
 	va_start(args, fmt);
 	vfprintf(fptr, fmt, args);
 	va_end(args);
